==> haskell-recv-0.1.1-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recv
version:              0.1.1
visibility:           public
id:                   recv-0.1.1-4wlkBqHps1EFCObuEBpudi
key:                  recv-0.1.1-4wlkBqHps1EFCObuEBpudi
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Efficient network recv
description:          Network recv based on buffer pools
category:             Network
abi:                  5800919f391582a5f1b111783c15e872
exposed:              True
exposed-modules:      Network.Socket.BufferPool
hidden-modules:
    Network.Socket.BufferPool.Buffer Network.Socket.BufferPool.Recv
    Network.Socket.BufferPool.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/recv-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recv-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recv-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recv
hs-libraries:         HSrecv-0.1.1-4wlkBqHps1EFCObuEBpudi
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-7upd0S3IeIT8lWw9Gu9EjE

haddock-interfaces:   /usr/share/doc/haskell-recv/html/recv.haddock
haddock-html:         /usr/share/doc/haskell-recv/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-recv-0.1.1-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-recv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 recv
version:              0.1.1
visibility:           public
id:                   recv-0.1.1-FUAi3ygNUtEOaY3jNIgoQ
key:                  recv-0.1.1-FUAi3ygNUtEOaY3jNIgoQ
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Efficient network recv
description:          Network recv based on buffer pools
category:             Network
abi:                  22be8a39028f2ab5ea0559b7f5913fd7
exposed:              True
exposed-modules:      Network.Socket.BufferPool
hidden-modules:
    Network.Socket.BufferPool.Buffer Network.Socket.BufferPool.Recv
    Network.Socket.BufferPool.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/recv-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/recv-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/recv-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-recv
hs-libraries:         HSrecv-0.1.1-FUAi3ygNUtEOaY3jNIgoQ
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-3.1.4.0-HbZCj3UHcZsFvn6ftFrD4m

haddock-interfaces:   /usr/share/doc/haskell-recv/html/recv.haddock
haddock-html:         /usr/share/doc/haskell-recv/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
